@@ -679,7 +679,13 @@ def start_introspection(uuid, **kwargs):
                       node_info=node_info)
             state = istate.States.starting
         else:
-            state = node_info.state
+            recorded_state = node_info.state
+            if istate.States.error == recorded_state:
+                # If there was a failure, return to starting state to avoid
+                # letting the cache block new runs from occuring.
+                state = istate.States.starting
+            else:
+                state = recorded_state
         return add_node(uuid, state, **kwargs)
 
 
@@ -958,10 +964,9 @@ def record_node(ironic=None, bmc_addresses=None, macs=None):
     if node.provision_state not in ir_utils.VALID_ACTIVE_STATES:
         raise utils.Error(_("Node %(node)s is not active, its provision "
                             "state is %(state)s") %
-                          {'node': node.uuid,
-                           'state': node.provision_state})
+                          {'node': node.id, 'state': node.provision_state})
 
-    return add_node(node.uuid, istate.States.waiting,
+    return add_node(node.id, istate.States.waiting,
                     manage_boot=False, mac=macs, bmc_address=bmc_addresses)
 
 
